@@ -49,9 +49,15 @@ case "${overlayroot}" in
         root="block:/dev/${root#UNIXNODE=}"
         rootok=1
     ;;
+    overlay:MAPPER=*|MAPPER=*) \
+        root="${root#overlay:}"
+        root="${root//\//\\x2f}"
+        root="block:/dev/mapper/${root#MAPPER=}"
+        rootok=1
+    ;;
     overlay:nbd=*) \
         root="${root#overlay:nbd=}"
-        root="block:/dev/${root}"
+        root="block:/dev/nbd0"
         need_network=1
         rootok=1
     ;;
