@@ -162,7 +162,7 @@ class BootImageKiwi(BootImageBase):
                 temp_boot_root_directory
             )
             data.sync_data(
-                options=['-a']
+                options=Defaults.get_sync_options()
             )
             boot_directory = temp_boot_root_directory + '/boot'
             Path.wipe(boot_directory)
@@ -199,10 +199,9 @@ class BootImageKiwi(BootImageBase):
             compress = Compress(
                 os.sep.join([self.target_dir, kiwi_initrd_basename])
             )
-            compress.xz(
+            self.initrd_filename = compress.xz(
                 ['--check=crc32', '--lzma2=dict=1MiB', '--threads=0']
             )
-            self.initrd_filename = compress.compressed_filename
 
     def cleanup(self) -> None:
         for directory in self.temp_directories:
