@@ -43,6 +43,8 @@ from kiwi.exceptions import (
     KiwiDiskGeometryError
 )
 
+import kiwi.defaults as defaults
+
 log = logging.getLogger('kiwi')
 
 
@@ -92,14 +94,41 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         else:
             self.boot_directory_name = 'grub'
 
+        if self.custom_args and 'grub_load_command' in self.custom_args:
+            self.grub_load = self.custom_args['grub_load_command']
+        else:
+            self.grub_load = 'source'
+
         if self.custom_args and 'config_options' in self.custom_args:
             self.config_options = self.custom_args['config_options']
 
-        self.terminal = self.xml_state.get_build_type_bootloader_console() \
-            or 'gfxterm'
+        terminal_output = self.xml_state.get_build_type_bootloader_console()[0]
+        terminal_input = self.xml_state.get_build_type_bootloader_console()[1]
+        terminal_input_grub = [
+            'console',
+            'serial',
+            'at_keyboard',
+            'usb_keyboard'
+        ]
+        terminal_output_grub = [
+            'console',
+            'serial',
+            'gfxterm',
+            'vga_text',
+            'mda_text',
+            'morse',
+            'spkmodem'
+        ]
+
+        self.terminal_output = \
+            terminal_output if terminal_output in terminal_output_grub else ''
+        self.terminal_input = \
+            terminal_input if terminal_input in terminal_input_grub else ''
+
         self.gfxmode = self.get_gfxmode('grub2')
         self.theme = self.get_boot_theme()
         self.timeout = self.get_boot_timeout_seconds()
+        self.bootpartition = self.xml_state.build_type.get_bootpartition()
         self.timeout_style = \
             self.xml_state.get_build_type_bootloader_timeout_style()
         self.displayname = self.xml_state.xml_data.get_displayname()
@@ -306,6 +335,12 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         """
         log.info('Creating grub2 install config file from template')
         self.iso_boot = True
+        has_graphics = False
+        has_serial = False
+        if 'gfxterm' in self.terminal_output:
+            has_graphics = True
+        if 'serial' in self.terminal_output or 'serial' in self.terminal_input:
+            has_serial = True
         parameters = {
             'search_params': '--file --set=root /boot/' + mbrid.get_id(),
             'default_boot': self.get_install_image_boot_default(),
@@ -321,12 +356,13 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'theme': self.theme,
             'boot_timeout': self.timeout,
             'boot_timeout_style': self.timeout_style or 'menu',
-            'serial_line_setup': self.serial_line_setup or 'serial',
+            'serial_line_setup': self.serial_line_setup or '',
             'title': self.get_menu_entry_install_title(),
             'bootpath': self.get_boot_path('iso'),
             'boot_directory_name': self.boot_directory_name,
             'efi_image_name': Defaults.get_efi_image_name(self.arch),
-            'terminal_setup': self.terminal
+            'terminal_input': self.terminal_input,
+            'terminal_output': self.terminal_output
         }
         custom_template_path = self._get_custom_template()
         if custom_template_path:
@@ -337,14 +373,14 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             log.info('--> Using multiboot install template')
             parameters['hypervisor'] = hypervisor
             template = self.grub2.get_multiboot_install_template(
-                self.failsafe_boot, self.terminal,
+                self.failsafe_boot, has_graphics, has_serial,
                 self.continue_on_timeout
             )
         else:
             log.info('--> Using standard boot install template')
             hybrid_boot = True
             template = self.grub2.get_install_template(
-                self.failsafe_boot, hybrid_boot, self.terminal,
+                self.failsafe_boot, hybrid_boot, has_graphics, has_serial,
                 self.continue_on_timeout
             )
         try:
@@ -371,6 +407,12 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         """
         log.info('Creating grub2 live ISO config file from template')
         self.iso_boot = True
+        has_graphics = False
+        has_serial = False
+        if 'gfxterm' in self.terminal_output:
+            has_graphics = True
+        if 'serial' in self.terminal_output or 'serial' in self.terminal_input:
+            has_serial = True
         parameters = {
             'search_params': '--file --set=root /boot/' + mbrid.get_id(),
             'default_boot': '0',
@@ -386,12 +428,13 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             'theme': self.theme,
             'boot_timeout': self.timeout,
             'boot_timeout_style': self.timeout_style or 'menu',
-            'serial_line_setup': self.serial_line_setup or 'serial',
+            'serial_line_setup': self.serial_line_setup or '',
             'title': self.get_menu_entry_title(plain=True),
             'bootpath': self.get_boot_path('iso'),
             'boot_directory_name': self.boot_directory_name,
             'efi_image_name': Defaults.get_efi_image_name(self.arch),
-            'terminal_setup': self.terminal
+            'terminal_input': self.terminal_input,
+            'terminal_output': self.terminal_output
         }
         custom_template_path = self._get_custom_template()
         if custom_template_path:
@@ -402,14 +445,15 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             log.info('--> Using multiboot template')
             parameters['hypervisor'] = hypervisor
             template = self.grub2.get_multiboot_iso_template(
-                self.failsafe_boot, self.terminal, self.mediacheck_boot
+                self.failsafe_boot, has_graphics, has_serial,
+                self.mediacheck_boot
             )
         else:
             log.info('--> Using standard boot template')
             hybrid_boot = True
             template = self.grub2.get_iso_template(
                 self.failsafe_boot, hybrid_boot,
-                self.terminal, self.mediacheck_boot
+                has_graphics, has_serial, self.mediacheck_boot
             )
         try:
             self.config = template.substitute(parameters)
@@ -675,7 +719,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         * GRUB_CMDLINE_LINUX
         * GRUB_CMDLINE_LINUX_DEFAULT
         * GRUB_GFXMODE
-        * GRUB_TERMINAL
+        * GRUB_TERMINAL_INPUT
+        * GRUB_TERMINAL_OUTPUT
         * GRUB_DISTRIBUTOR
         * GRUB_DISABLE_LINUX_UUID
         * GRUB_DISABLE_LINUX_PARTUUID
@@ -688,9 +733,16 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         # elements to set in any case
         grub_default_entries = {
             'GRUB_TIMEOUT': self.timeout,
-            'GRUB_GFXMODE': self.gfxmode,
-            'GRUB_TERMINAL': '"{0}"'.format(self.terminal)
+            'GRUB_GFXMODE': self.gfxmode
         }
+        if self.terminal_input:
+            grub_default_entries['GRUB_TERMINAL_INPUT'] = '"{0}"'.format(
+                self.terminal_input
+            )
+        if self.terminal_output:
+            grub_default_entries['GRUB_TERMINAL_OUTPUT'] = '"{0}"'.format(
+                self.terminal_output
+            )
         grub_final_cmdline = re.sub(
             r'(^root=[^\s]+)|( root=[^\s]+)', '', self.cmdline
         ).strip()
@@ -718,8 +770,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             grub_default_entries['GRUB_CMDLINE_LINUX_DEFAULT'] = '"{0}"'.format(
                 grub_final_cmdline
             )
-        if self.terminal and 'serial' in self.terminal and \
-           self.serial_line_setup:
+        if self.serial_line_setup and \
+           ('serial' in self.terminal_input or 'serial' in self.terminal_output):
             grub_default_entries['GRUB_SERIAL_COMMAND'] = '"{0}"'.format(
                 self.serial_line_setup
             )
@@ -881,7 +933,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 uuid, mbrid, lookup_path
             )
 
-    def _setup_bios_image(self, mbrid=None, lookup_path=None):
+    def _setup_bios_image(self, mbrid, lookup_path=None):
         """
         Provide bios grub image
         """
@@ -919,7 +971,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         Must be called after setup_install_boot_images and write.
         """
         fat_image_mbsize = int(
-            self.xml_state.build_type.get_efifatimagesize() or 20
+            self.xml_state.build_type
+                .get_efifatimagesize() or defaults.EFI_FAT_IMAGE_SIZE
         )
         Command.run(
             ['qemu-img', 'create', path, f'{fat_image_mbsize}M']
@@ -975,7 +1028,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 '-O', Defaults.get_efi_module_directory_name(self.arch),
                 '-o', root_efi_image,
                 '-c', root_efi_path + 'earlyboot.cfg',
-                '-p', self.get_boot_path() + '/' + self.boot_directory_name,
+                '-p', os.path.join(self.get_boot_path(), self.boot_directory_name),
                 '-d', module_path.replace(self.root_dir, '')
             ] + module_list
         )
@@ -1007,7 +1060,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 efi_boot_config, mbrid
             )
 
-    def _create_bios_image(self, mbrid=None, lookup_path=None):
+    def _create_bios_image(self, mbrid, lookup_path=None):
         early_boot_script = os.path.normpath(
             os.sep.join([self._get_grub2_boot_path(), 'earlyboot.cfg'])
         )
@@ -1088,14 +1141,14 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
                 'search --fs-uuid --set=root {0}{1}'.format(uuid, os.linesep)
             )
             early_boot.write(
-                'set prefix=($root){0}/{1}{2}'.format(
-                    self.get_boot_path(), self.boot_directory_name, os.linesep
+                'set prefix=($root){0}{1}'.format(
+                    os.path.join(self.get_boot_path(), self.boot_directory_name), os.linesep
                 )
             )
             early_boot.write(
-                'source ($root){0}/{1}/grub.cfg{2}'.format(
-                    self.get_boot_path(), self.boot_directory_name, os.linesep
-                )
+                '{0} ($root){1}/grub.cfg{2}'.format(self.grub_load, os.path.join(
+                    self.get_boot_path(), self.boot_directory_name
+                ), os.linesep)
             )
 
     def _create_early_boot_script_for_mbrid_search(self, filename, mbrid):
@@ -1103,19 +1156,23 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             early_boot.write(
                 'set btrfs_relative_path="yes"{0}'.format(os.linesep)
             )
-            early_boot.write(
-                'search --file --set=root /boot/mbrid{0}'.format(
-                    os.linesep
+            if mbrid:
+                early_boot.write(
+                    f'search --file --set=root /boot/{mbrid.get_id()}{os.linesep}'
+                )
+            else:
+                # Fallback search for /boot/mbrid
+                early_boot.write(
+                    f'search --file --set=root /boot/mbrid{os.linesep}'
                 )
-            )
             early_boot.write(
                 'set prefix=($root)/boot/{0}{1}'.format(
                     self.boot_directory_name, os.linesep
                 )
             )
             early_boot.write(
-                'source ($root)/boot/{0}/grub.cfg{1}'.format(
-                    self.boot_directory_name, os.linesep
+                '{0} ($root)/boot/{1}/grub.cfg{2}'.format(
+                    self.grub_load, self.boot_directory_name, os.linesep
                 )
             )
 
@@ -1284,7 +1341,8 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
             if not os.path.exists(theme_dir):
                 log.warning('Theme %s not found', theme_dir)
                 log.warning('Set bootloader terminal to console mode')
-                self.terminal = 'console'
+                self.terminal_input = 'console'
+                self.terminal_output = 'console'
 
     def _setup_EFI_path(self, lookup_path):
         """
@@ -1333,7 +1391,7 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         )
 
     def _fix_grub_to_support_dynamic_efi_and_bios_boot(self, config_file):
-        if self.firmware.efi_mode():
+        if self.firmware.efi_mode() and self.arch in ['x86_64', 'ix86']:
             # On systems that are configured to use EFI with grub2
             # there is no support for dynamic EFI environment checking.
             # In this condition we change the grub config to add this
@@ -1449,12 +1507,24 @@ class BootLoaderConfigGrub2(BootLoaderConfigBase):
         )
         for menu_entry_file in glob.iglob(loader_entries_pattern):
             with open(menu_entry_file) as grub_menu_entry_file:
-                menu_entry = grub_menu_entry_file.read()
-                menu_entry = re.sub(
-                    r'(linux|initrd) .*(/boot.*)',
-                    r'\1 \2',
-                    menu_entry
-                )
+                menu_entry = grub_menu_entry_file.read().split(os.linesep)
+
+            for line_number, menu_entry_line in enumerate(menu_entry):
+                if bool(re.match(r'^(linux|initrd) .*', menu_entry_line)):
+
+                    log.debug(f'Existing loader entry: {menu_entry_line}')
+                    config_path = menu_entry_line.split(' ', 1)[0]
+
+                    basename = os.path.basename(menu_entry_line)
+                    if self.bootpartition:
+                        config_path = (f'{config_path} /{basename}')
+                    else:
+                        config_path = (f'{config_path} /boot/{basename}')
+
+                    menu_entry[line_number] = config_path
+                    log.debug(f'Updated loader entry: {config_path}')
+
+            menu_entry = os.linesep.join(menu_entry)
             with open(menu_entry_file, 'w') as grub_menu_entry_file:
                 grub_menu_entry_file.write(menu_entry)
 
