@@ -17,6 +17,7 @@
 #
 import glob
 import os
+import re
 import logging
 
 # project
@@ -51,6 +52,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                 {
                     'target_removable': bool,
                     'system_volumes': list_of_volumes,
+                    'system_root_volume': root volume name if required
                     'firmware': FirmWare_instance,
                     'efi_device': string,
                     'boot_device': string,
@@ -70,12 +72,15 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
         self.proc_mount = None
         self.sysfs_mount = None
         self.volumes = None
+        self.root_volume_name = None
         self.volumes_mount = []
         self.target_removable = None
         if custom_args and 'target_removable' in custom_args:
             self.target_removable = custom_args['target_removable']
         if custom_args and 'system_volumes' in custom_args:
             self.volumes = custom_args['system_volumes']
+        if custom_args and 'system_root_volume' in custom_args:
+            self.root_volume_name = custom_args['system_root_volume']
         if custom_args and 'firmware' in custom_args:
             self.firmware = custom_args['firmware']
         if custom_args and 'install_options' in custom_args:
@@ -278,12 +283,33 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
                 # restore the grub installer noop
                 self._enable_grub2_install(self.root_mount.mountpoint)
 
+    def set_disk_password(self, password: str):
+        if self.root_mount and password is not None:
+            log.debug('Include cryptomount credentials...')
+            config_file = '{0}/boot/efi/EFI/BOOT/grub.cfg'.format(
+                self.root_mount.mountpoint
+            )
+            if os.path.isfile(config_file):
+                with open(config_file) as config:
+                    grub_config = config.read()
+                    grub_config = re.sub(
+                        r'cryptomount',
+                        f'cryptomount -p "{password}"',
+                        grub_config
+                    )
+                with open(config_file, 'w') as grub_config_file:
+                    grub_config_file.write(grub_config)
+                    log.debug(f'<<< {grub_config} >>>')
+
     def _mount_device_and_volumes(self):
         if self.root_mount is None:
             self.root_mount = MountManager(
                 device=self.custom_args['root_device']
             )
-            self.root_mount.mount()
+            custom_root_mount_args = []
+            if self.root_volume_name and self.root_volume_name != '/':
+                custom_root_mount_args += [f'subvol={self.root_volume_name}']
+            self.root_mount.mount(options=custom_root_mount_args)
 
         if self.boot_mount is None:
             if 's390' in self.arch:
@@ -373,7 +399,7 @@ class BootLoaderInstallGrub2(BootLoaderInstallBase):
             grub2_install_backup = ''.join(
                 [grub2_install, '.orig']
             )
-            if os.path.exists(grub2_install_backup):
+            if os.path.exists(''.join([root_path, grub2_install_backup])):
                 Command.run(
                     [
                         'chroot', root_path,
