@@ -76,6 +76,7 @@ class KisBuilder:
             xml_state, target_dir, root_dir,
             signing_keys=self.boot_signing_keys
         )
+        self.bundle_format = xml_state.get_build_type_bundle_format()
         self.image_name = ''.join(
             [
                 target_dir, '/',
@@ -123,8 +124,7 @@ class KisBuilder:
             if self.compressed:
                 log.info('xz compressing root filesystem image')
                 compress = Compress(self.image)
-                compress.xz(self.xz_options)
-                self.image = compress.compressed_filename
+                self.image = compress.xz(self.xz_options)
 
             log.info('Creating root filesystem MD5 checksum')
             checksum = Checksum(self.image)
@@ -236,7 +236,11 @@ class KisBuilder:
             self.runtime_config.get_max_size_constraint(),
             self.archive_name
         )
-        # store results
+        # store image bundle_format in result
+        if self.bundle_format:
+            self.result.add_bundle_format(self.bundle_format)
+
+        # # store archive file name in result
         self.result.add(
             key='kis_archive',
             filename=self.archive_name,
