@@ -85,6 +85,7 @@ SHARED_CACHE_DIR = '/var/cache/kiwi'
 TEMP_DIR = '/var/tmp'
 CUSTOM_RUNTIME_CONFIG_FILE = None
 PLATFORM_MACHINE = platform.machine()
+EFI_FAT_IMAGE_SIZE = 20
 
 log = logging.getLogger('kiwi')
 
@@ -1790,6 +1791,9 @@ class Defaults:
 
         :rtype: str
         """
+        host_architecture = Defaults.get_platform_name()
+        if 's390' in host_architecture:
+            return 'kpartx'
         return 'partx'
 
     @staticmethod
