@@ -40,6 +40,8 @@ from kiwi.exceptions import (
     KiwiRuntimeError
 )
 
+import kiwi.defaults as defaults
+
 dracut_module_type = NamedTuple(
     'dracut_module_type', [
         ('package', str),
@@ -886,8 +888,10 @@ class RuntimeChecker:
 
             <package name="{0}"/>
         ''')
+        initrd_system = self.xml_state.get_initrd_system()
         required_dracut_package = 'dracut-kiwi-overlay'
-        if self.xml_state.build_type.get_overlayroot():
+        if initrd_system == 'dracut' and \
+           self.xml_state.build_type.get_overlayroot():
             package_names = \
                 self.xml_state.get_bootstrap_packages() + \
                 self.xml_state.get_system_packages()
@@ -1040,6 +1044,26 @@ class RuntimeChecker:
                     )
                 )
 
+    def check_efi_fat_image_has_correct_size(self) -> None:
+        """
+        Verify that the efifatimagesize does not exceed the max
+        El Torito load size of 65535 * 512 bytes
+        """
+        message = dedent('''\n
+            El Torito max load size exceeded
+
+            The configured efifatimagesize of '{0}MB' exceeds
+            the El Torito max load size of 65535 * 512 bytes (~31MB).
+        ''')
+        fat_image_mbsize = int(
+            self.xml_state.build_type
+                .get_efifatimagesize() or defaults.EFI_FAT_IMAGE_SIZE
+        )
+        if fat_image_mbsize > 31:
+            raise KiwiRuntimeError(
+                message.format(fat_image_mbsize)
+            )
+
     @staticmethod
     def _get_dracut_module_version_from_pdb(
         package_manager: str, package_name: str, root_dir: str
