@@ -70,10 +70,17 @@ class DiskSetup:
         self.root_dir = root_dir
         self.xml_state = xml_state
 
-    def get_disksize_mbytes(self) -> int:
+    def get_disksize_mbytes(
+        self, root_clone: int = 0, boot_clone: int = 0
+    ) -> int:
         """
         Precalculate disk size requirements in mbytes
 
+        :param int root_clone:
+            root partition gets cloned, N+1 times the size is needed
+        :param int boot_clone:
+            boot partition gets cloned, N+1 times the size is needed
+
         :return: disk size mbytes
 
         :rtype: int
@@ -83,6 +90,14 @@ class DiskSetup:
         root_filesystem_mbytes = self.rootsize.customize(
             self.rootsize.accumulate_mbyte_file_sizes(), self.filesystem
         )
+        if root_clone:
+            root_clone += 1
+            log.info(
+                '--> root partition is clone: {0}*{1} MB'.format(
+                    root_clone, root_filesystem_mbytes
+                )
+            )
+            root_filesystem_mbytes *= root_clone
         calculated_disk_mbytes += root_filesystem_mbytes
         log.info(
             '--> system data with filesystem overhead needs %s MB',
@@ -125,6 +140,14 @@ class DiskSetup:
 
         boot_mbytes = self.boot_partition_size()
         if boot_mbytes:
+            if boot_clone:
+                boot_clone += 1
+                log.info(
+                    '--> boot partition is clone: {0}*{1} MB'.format(
+                        boot_clone, boot_mbytes
+                    )
+                )
+                boot_mbytes *= boot_clone
             calculated_disk_mbytes += boot_mbytes
             log.info(
                 '--> boot partition adding %s MB', boot_mbytes
@@ -287,11 +310,26 @@ class DiskSetup:
         data_partition_mbytes = self._calculate_partition_mbytes()
         for map_name in sorted(self.custom_partitions.keys()):
             partition_mount_path = self.custom_partitions[map_name].mountpoint
+            partition_filesystem = self.custom_partitions[map_name].filesystem
+            partition_clone = self.custom_partitions[map_name].clone
             if partition_mount_path:
                 partition_mbsize = self.custom_partitions[map_name].mbsize
-                disk_add_mbytes = int(partition_mbsize) - \
-                    data_partition_mbytes.partition[partition_mount_path]
+                if partition_filesystem == 'squashfs':
+                    # cannot predict compressed size prior compressing
+                    # use size as configured
+                    disk_add_mbytes = int(partition_mbsize)
+                else:
+                    disk_add_mbytes = int(partition_mbsize) - \
+                        data_partition_mbytes.partition[partition_mount_path]
                 if disk_add_mbytes > 0:
+                    if partition_clone:
+                        partition_clone += 1
+                        log.info(
+                            '--> {0} partition is clone: {1}*{2} MB'.format(
+                                map_name, partition_clone, disk_add_mbytes
+                            )
+                        )
+                        disk_add_mbytes *= partition_clone
                     disk_partition_mbytes += disk_add_mbytes
                 else:
                     message = dedent('''\n
