@@ -184,10 +184,14 @@ class Profile:
         # kiwi_install_volid
         if self.xml_state.is_xen_server():
             self.dot_profile['kiwi_xendomain'] = 'dom0'
-        if self.xml_state.get_build_type_name() in ['oem', 'iso']:
+        if self.xml_state.get_build_type_name() == 'oem':
             install_volid = self.xml_state.build_type.get_volid() or \
                 Defaults.get_install_volume_id()
             self.dot_profile['kiwi_install_volid'] = install_volid
+        if self.xml_state.get_build_type_name() == 'iso':
+            live_iso_volid = self.xml_state.build_type.get_volid() or \
+                Defaults.get_volume_id()
+            self.dot_profile['kiwi_live_volid'] = live_iso_volid
 
     def _strip_to_profile(self):
         # kiwi_strip_delete
@@ -314,8 +318,10 @@ class Profile:
             type_section.get_firmware()
         self.dot_profile['kiwi_bootloader'] = \
             self.xml_state.get_build_type_bootloader_name()
-        self.dot_profile['kiwi_bootloader_console'] = \
-            self.xml_state.get_build_type_bootloader_console()
+        self.dot_profile['kiwi_bootloader_console'] = "{}:{}".format(
+            self.xml_state.get_build_type_bootloader_console()[0] or 'default',
+            self.xml_state.get_build_type_bootloader_console()[1] or 'default'
+        )
         self.dot_profile['kiwi_btrfs_root_is_snapshot'] = \
             type_section.get_btrfs_root_is_snapshot()
         self.dot_profile['kiwi_gpt_hybrid_mbr'] = \
