@@ -67,8 +67,8 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             self.custom_args['root_label'] = 'ROOT'
         if 'root_is_snapshot' not in self.custom_args:
             self.custom_args['root_is_snapshot'] = False
-        if 'set_default_volume' not in self.custom_args:
-            self.custom_args['set_default_volume'] = True
+        if 'btrfs_default_volume_requested' not in self.custom_args:
+            self.custom_args['btrfs_default_volume_requested'] = True
         if 'root_is_readonly_snapshot' not in self.custom_args:
             self.custom_args['root_is_readonly_snapshot'] = False
         if 'root_is_subvolume' not in self.custom_args:
@@ -229,6 +229,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                 )
 
                 volume_mountpoint = toplevel
+                root_is_snapshot = self.custom_args['root_is_snapshot']
 
                 attributes = {
                     'parent': volume.parent or '',
@@ -239,7 +240,7 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     ).lstrip(os.sep),
                     'subvol_name': volume.name
                 }
-                if self.custom_args['root_is_snapshot']:
+                if root_is_snapshot:
                     volume_mountpoint = self.mountpoint + \
                         f'/{self.root_volume_name}/.snapshots/1/snapshot/'
                     attributes = {
@@ -255,7 +256,13 @@ class VolumeManagerBtrfs(VolumeManagerBase):
                     device=self.device,
                     attributes=attributes,
                     mountpoint=os.path.normpath(
-                        volume_mountpoint + os.sep + volume.realpath
+                        os.sep.join(
+                            [
+                                volume_mountpoint,
+                                self.root_volume_name if not root_is_snapshot else '',
+                                volume.realpath
+                            ]
+                        )
                     )
                 )
                 self.subvol_mount_list.append(
@@ -476,12 +483,12 @@ class VolumeManagerBtrfs(VolumeManagerBase):
             ['btrfs', 'subvolume', 'list', self.mountpoint]
         )
         for subvolume in subvolume_list_call.output.split('\n'):
-            id_search = re.search('ID (\d+) .*path (.*)', subvolume)
+            id_search = re.search(r'ID (\d+) .*path (.*)', subvolume)
             if id_search:
                 volume_id = id_search.group(1)
                 volume_path = id_search.group(2)
                 if volume_path == default_volume:
-                    if self.custom_args['set_default_volume'] is not False:
+                    if self.custom_args['btrfs_default_volume_requested']:
                         Command.run(
                             [
                                 'btrfs', 'subvolume', 'set-default',
