@@ -168,6 +168,18 @@ class XMLState:
         """
         return self.build_type.get_image()
 
+    def btrfs_default_volume_requested(self) -> bool:
+        """
+        Check if setting a default volume for btrfs is requested
+        """
+        if self.build_type.get_btrfs_set_default_volume() is False:
+            # Setting a default volume is explicitly switched off
+            return False
+        else:
+            # In any other case (True | None) a default volume
+            # is wanted and will be set
+            return True
+
     def get_image_version(self) -> str:
         """
         Image version from preferences section.
@@ -964,18 +976,28 @@ class XMLState:
         return bootloader.get_name() if bootloader else \
             Defaults.get_default_bootloader()
 
-    def get_build_type_bootloader_console(self) -> Optional[str]:
+    def get_build_type_bootloader_console(self) -> List[str]:
         """
         Return bootloader console setting for selected build type
 
-        :return: console string
+        :return:
+            list of console settings for output (first element)
+            and input (second element)
 
-        :rtype: str
+        :rtype: list
         """
+        result = ['', '']
         bootloader = self.get_build_type_bootloader_section()
         if bootloader:
-            return bootloader.get_console()
-        return None
+            combined_console = bootloader.get_console()
+            if combined_console:
+                console_out, *console_in = combined_console.split(' ')[:2]
+                console_in = console_out if not console_in else console_in[0]
+                result = [
+                    console_out if console_out != 'none' else '',
+                    console_in if console_in != 'none' else ''
+                ]
+        return result
 
     def get_build_type_bootloader_serial_line_setup(self) -> Optional[str]:
         """
@@ -1900,9 +1922,22 @@ class XMLState:
         Get list of signing keys specified on the repositories
         """
         key_file_list: List[str] = []
+        release_version = self.get_release_version()
+        release_vars = [
+            '$releasever',
+            '${releasever}'
+        ]
         for repository in self.get_repository_sections() or []:
             for signing in repository.get_source().get_signing() or []:
-                key_file_list.append(Uri(signing.get_key()).translate())
+                normalized_key_url = Uri(signing.get_key()).translate()
+                if release_version:
+                    for release_var in release_vars:
+                        if release_var in normalized_key_url:
+                            normalized_key_url = normalized_key_url.replace(
+                                release_var, release_version
+                            )
+                if normalized_key_url not in key_file_list:
+                    key_file_list.append(normalized_key_url)
         return key_file_list
 
     def set_repository(
@@ -2781,7 +2816,7 @@ class XMLState:
         return name
 
     def _to_mega_byte(self, size):
-        value = re.search('(\d+)([MG]*)', format(size))
+        value = re.search(r'(\d+)([MG]*)', format(size))
         if value:
             number = value.group(1)
             unit = value.group(2)
