@@ -112,6 +112,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader = BootLoaderConfigGrub2(
             self.state, 'root_dir', None, {
                 'grub_directory_name': 'grub2',
+                'grub_load_command': 'source',
                 'boot_is_crypto': True,
                 'crypto_disk': True,
                 'targetbase': 'rootdev',
@@ -139,6 +140,17 @@ class TestBootLoaderConfigGrub2:
         bootloader = BootLoaderConfigGrub2(xml_state, 'root_dir')
         assert bootloader.boot_directory_name == 'grub'
 
+    @patch('kiwi.bootloader.config.grub2.Path.which')
+    def test_post_init_grub2_load_command(self, mock_which):
+        Defaults.set_platform_name('i686')
+        xml_state = MagicMock()
+        xml_state.build_type.get_firmware = Mock(
+            return_value=None
+        )
+        mock_which.return_value = None
+        bootloader = BootLoaderConfigGrub2(xml_state, 'root_dir')
+        assert bootloader.grub_load == 'source'
+
     def test_post_init_invalid_platform(self):
         Defaults.set_platform_name('unsupported-arch')
         with raises(KiwiBootLoaderGrubPlatformError):
@@ -566,7 +578,8 @@ class TestBootLoaderConfigGrub2:
         grub_default.write = Mock()
         mock_sysconfig.return_value = grub_default
         mock_exists.return_value = True
-        self.bootloader.terminal = 'serial'
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'gfxterm'
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
         self.firmware.efi_mode.return_value = 'efi'
@@ -584,7 +597,8 @@ class TestBootLoaderConfigGrub2:
             'GRUB_ENABLE_CRYPTODISK': 'y',
             'GRUB_GFXMODE': '800x600',
             'GRUB_SERIAL_COMMAND': '"serial --speed=38400"',
-            'GRUB_TERMINAL': '"serial"',
+            'GRUB_TERMINAL_INPUT': '"serial"',
+            'GRUB_TERMINAL_OUTPUT': '"gfxterm"',
             'GRUB_THEME': '/boot/grub2/themes/openSUSE/theme.txt',
             'GRUB_TIMEOUT': 10,
             'GRUB_TIMEOUT_STYLE': 'countdown',
@@ -606,7 +620,8 @@ class TestBootLoaderConfigGrub2:
         grub_default = MagicMock()
         mock_sysconfig.return_value = grub_default
         mock_exists.return_value = True
-        self.bootloader.terminal = 'serial'
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'serial'
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
         self.bootloader.cmdline = 'root=LABEL=some-label'
@@ -630,7 +645,8 @@ class TestBootLoaderConfigGrub2:
             call(
                 'GRUB_SERIAL_COMMAND', '"serial --speed=38400"'
             ),
-            call('GRUB_TERMINAL', '"serial"'),
+            call('GRUB_TERMINAL_INPUT', '"serial"'),
+            call('GRUB_TERMINAL_OUTPUT', '"serial"'),
             call('GRUB_THEME', '/boot/grub2/themes/openSUSE/theme.txt'),
             call('GRUB_TIMEOUT', 10),
             call('GRUB_TIMEOUT_STYLE', 'countdown'),
@@ -650,7 +666,8 @@ class TestBootLoaderConfigGrub2:
         grub_default = MagicMock()
         mock_sysconfig.return_value = grub_default
         mock_exists.return_value = True
-        self.bootloader.terminal = 'serial'
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'serial'
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
         self.bootloader.cmdline = 'root=UUID=foo'
@@ -672,7 +689,8 @@ class TestBootLoaderConfigGrub2:
             call(
                 'GRUB_SERIAL_COMMAND', '"serial --speed=38400"'
             ),
-            call('GRUB_TERMINAL', '"serial"'),
+            call('GRUB_TERMINAL_INPUT', '"serial"'),
+            call('GRUB_TERMINAL_OUTPUT', '"serial"'),
             call('GRUB_THEME', '/boot/grub2/themes/openSUSE/theme.txt'),
             call('GRUB_TIMEOUT', 10),
             call('GRUB_TIMEOUT_STYLE', 'countdown'),
@@ -691,7 +709,8 @@ class TestBootLoaderConfigGrub2:
         grub_default = MagicMock()
         mock_sysconfig.return_value = grub_default
         mock_exists.return_value = True
-        self.bootloader.terminal = 'serial'
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'serial'
         self.bootloader.theme = 'openSUSE'
         self.bootloader.displayname = 'Bob'
         self.bootloader.cmdline = 'abcd root=LABEL=foo console=tty0'
@@ -715,7 +734,8 @@ class TestBootLoaderConfigGrub2:
             call(
                 'GRUB_SERIAL_COMMAND', '"serial --speed=38400"'
             ),
-            call('GRUB_TERMINAL', '"serial"'),
+            call('GRUB_TERMINAL_INPUT', '"serial"'),
+            call('GRUB_TERMINAL_OUTPUT', '"serial"'),
             call('GRUB_THEME', '/boot/grub2/themes/openSUSE/theme.txt'),
             call('GRUB_TIMEOUT', 10),
             call('GRUB_TIMEOUT_STYLE', 'countdown'),
@@ -869,7 +889,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.multiboot = True
         self.bootloader.setup_live_image_config(self.mbrid)
         self.grub2.get_multiboot_iso_template.assert_called_once_with(
-            True, 'gfxterm', None
+            True, False, False, None
         )
 
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
@@ -879,21 +899,25 @@ class TestBootLoaderConfigGrub2:
         self.firmware.efi_mode = Mock(
             return_value='uefi'
         )
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'gfxterm'
         self.bootloader.early_boot_script_efi = 'earlyboot.cfg'
         self.bootloader.multiboot = False
         self.bootloader.setup_live_image_config(self.mbrid)
         self.grub2.get_iso_template.assert_called_once_with(
-            True, True, 'gfxterm', None
+            True, True, True, True, None
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
             'root_dir', 'earlyboot.cfg', 'iso'
         )
 
     def test_setup_install_image_config_multiboot(self):
+        self.bootloader.terminal_input = 'serial'
+        self.bootloader.terminal_output = 'gfxterm'
         self.bootloader.multiboot = True
         self.bootloader.setup_install_image_config(self.mbrid)
         self.grub2.get_multiboot_install_template.assert_called_once_with(
-            True, 'gfxterm', True
+            True, True, True, True
         )
 
     @patch.object(BootLoaderConfigGrub2, '_mount_system')
@@ -1010,6 +1034,20 @@ class TestBootLoaderConfigGrub2:
             assert 'initrd /boot/initrd' in \
                 file_handle_menu.write.call_args_list[1][0][0].split(os.linesep)
 
+            self.bootloader.bootpartition = True
+            file_handle_menu.reset_mock()
+
+            self.bootloader.setup_disk_image_config(
+                boot_options={
+                    'root_device': 'rootdev', 'boot_device': 'bootdev'
+                }
+            )
+
+            assert 'linux /vmlinuz' in \
+                file_handle_menu.write.call_args_list[1][0][0].split(os.linesep)
+            assert 'initrd /initrd' in \
+                file_handle_menu.write.call_args_list[1][0][0].split(os.linesep)
+
     @patch.object(BootLoaderConfigGrub2, '_mount_system')
     @patch.object(BootLoaderConfigGrub2, '_copy_grub_config_to_efi_path')
     @patch('kiwi.bootloader.config.grub2.Command.run')
@@ -1078,7 +1116,7 @@ class TestBootLoaderConfigGrub2:
         self.bootloader.multiboot = False
         self.bootloader.setup_install_image_config(self.mbrid)
         self.grub2.get_install_template.assert_called_once_with(
-            True, True, 'gfxterm', True
+            True, True, False, False, True
         )
         mock_copy_grub_config_to_efi_path.assert_called_once_with(
             'root_dir', 'earlyboot.cfg', 'iso'
@@ -1267,8 +1305,8 @@ class TestBootLoaderConfigGrub2:
                 call('cryptomount -u 0815\n'),
                 call('set root="cryptouuid/0815"\n'),
                 call('search --fs-uuid --set=root 0815\n'),
-                call('set prefix=($root)//grub2\n'),
-                call('source ($root)//grub2/grub.cfg\n')
+                call('set prefix=($root)/grub2\n'),
+                call('source ($root)/grub2/grub.cfg\n')
             ]
         assert mock_command.call_args_list == [
             call(
@@ -1283,7 +1321,7 @@ class TestBootLoaderConfigGrub2:
                     '-O', 'x86_64-efi',
                     '-o', '/boot/efi/EFI/BOOT/bootx64.efi',
                     '-c', '/boot/efi/EFI/BOOT/earlyboot.cfg',
-                    '-p', '//grub2',
+                    '-p', '/grub2',
                     '-d', '/usr/share/grub2/x86_64-efi',
                     'ext2', 'iso9660', 'linux', 'echo', 'configfile',
                     'search_label', 'search_fs_file', 'search',
@@ -1326,8 +1364,8 @@ class TestBootLoaderConfigGrub2:
                 call('cryptomount -u 0815\n'),
                 call('set root="cryptouuid/0815"\n'),
                 call('search --fs-uuid --set=root 0815\n'),
-                call('set prefix=($root)//grub2\n'),
-                call('source ($root)//grub2/grub.cfg\n')
+                call('set prefix=($root)/grub2\n'),
+                call('source ($root)/grub2/grub.cfg\n')
             ]
             mock_open.assert_called_once_with(
                 'root_dir/boot/efi/EFI/BOOT/grub.cfg', 'w'
@@ -1732,11 +1770,11 @@ class TestBootLoaderConfigGrub2:
             ]
             assert file_handle.write.call_args_list == [
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/mbrid\n'),
+                call('search --file --set=root /boot/0xffffffff\n'),
                 call('set prefix=($root)/boot/grub2\n'),
                 call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/mbrid\n'),
+                call('search --file --set=root /boot/0xffffffff\n'),
                 call('set prefix=($root)/boot/grub2\n'),
                 call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('source /boot/grub2/grub.cfg\n')
@@ -1845,7 +1883,7 @@ class TestBootLoaderConfigGrub2:
 
             assert file_handle.write.call_args_list == [
                 call('set btrfs_relative_path="yes"\n'),
-                call('search --file --set=root /boot/mbrid\n'),
+                call('search --file --set=root /boot/0xffffffff\n'),
                 call('set prefix=($root)/boot/grub2\n'),
                 call('source ($root)/boot/grub2/grub.cfg\n'),
                 call('source /boot/grub2/grub.cfg\n')
@@ -1876,6 +1914,19 @@ class TestBootLoaderConfigGrub2:
             )
         ]
 
+        with patch('builtins.open', create=True) as mock_open:
+            # Test fallback search for earlyboot if UUID and MBR ID are missing
+            mock_open.return_value = MagicMock(spec=io.IOBase)
+            file_handle = mock_open.return_value.__enter__.return_value
+            self.bootloader._setup_efi_image(uuid=None, mbrid=None)
+
+            assert file_handle.write.call_args_list == [
+                call('set btrfs_relative_path="yes"\n'),
+                call('search --file --set=root /boot/mbrid\n'),
+                call('set prefix=($root)/boot/grub2\n'),
+                call('source ($root)/boot/grub2/grub.cfg\n'),
+            ]
+
     @patch.object(BootLoaderConfigGrub2, '_supports_bios_modules')
     @patch('kiwi.bootloader.config.grub2.Command.run')
     @patch('os.path.exists')
@@ -1915,7 +1966,7 @@ class TestBootLoaderConfigGrub2:
                 )
                 assert file_handle.write.call_args_list == [
                     call('set btrfs_relative_path="yes"\n'),
-                    call('search --file --set=root /boot/mbrid\n'),
+                    call('search --file --set=root /boot/0xffffffff\n'),
                     call('set prefix=($root)/boot/grub2\n'),
                     call('source ($root)/boot/grub2/grub.cfg\n'),
                     call('source /boot/grub2/grub.cfg\n')
@@ -2095,7 +2146,8 @@ class TestBootLoaderConfigGrub2:
         with patch('builtins.open'):
             with self._caplog.at_level(logging.WARNING):
                 self.bootloader.setup_install_boot_images(self.mbrid)
-                assert self.bootloader.terminal == 'console'
+                assert self.bootloader.terminal_input == 'console'
+                assert self.bootloader.terminal_output == 'console'
 
     @patch.object(BootLoaderConfigGrub2, 'setup_install_boot_images')
     def test_setup_live_boot_images(self, mock_setup_install_boot_images):
