@@ -89,6 +89,9 @@ class TestDefaults:
         assert Defaults.get_unsigned_grub_loader('root') == \
             mock_glob.return_value.pop()
         mock_glob.assert_called_once_with('root/usr/share/grub*/*-efi/grub.efi')
+        mock_glob.reset_mock()
+        mock_glob.return_value = []
+        assert Defaults.get_unsigned_grub_loader('root') is None
 
     def test_is_x86_arch(self):
         assert Defaults.is_x86_arch('x86_64') is True
