@@ -1,4 +1,5 @@
 from pytest import raises
+from mock import patch
 
 from kiwi.oci_tools.base import OCIBase
 
@@ -7,6 +8,9 @@ class TestOCIBase:
     def setup(self):
         self.oci = OCIBase()
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_init_container(self):
         with raises(NotImplementedError):
             self.oci.init_container()
@@ -44,3 +48,14 @@ class TestOCIBase:
     def test_post_process(self):
         with raises(NotImplementedError):
             self.oci.post_process()
+
+    @patch('kiwi.oci_tools.base.Path.which')
+    @patch('kiwi.oci_tools.base.CommandCapabilities.check_version')
+    def test_skopeo_provides_tmpdir_option(
+        self, mock_Path_which, mock_CommandCapabilities_check_version
+    ):
+        mock_Path_which.return_value = 'skopeo'
+        mock_CommandCapabilities_check_version.return_value = (0, 2, 0)
+        assert self.oci._skopeo_provides_tmpdir_option() is True
+        mock_Path_which.return_value = None
+        assert self.oci._skopeo_provides_tmpdir_option() is False
