@@ -47,6 +47,13 @@ class TestPath:
         Path.wipe('foo')
         assert not mock_command.called
 
+    @patch('kiwi.command.Command.run')
+    def test_rename(self, mock_command):
+        Path.rename('cur', 'new')
+        mock_command.assert_called_once_with(
+            ['mv', 'cur', 'new']
+        )
+
     @patch('kiwi.command.Command.run')
     def test_remove(self, mock_command):
         Path.remove('foo')
