@@ -29,6 +29,9 @@ class TestDiskFormatVhd:
             self.xml_state, 'root_dir', 'target_dir'
         )
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_post_init(self):
         self.disk_format.post_init({'option': 'value'})
         assert self.disk_format.options == ['-o', 'option=value']
