@@ -67,7 +67,7 @@ class TestSystemPrepare:
             root_init
         )
         root_bind.setup_intermediate_config.assert_called_once_with()
-        root_bind.mount_kernel_file_systems.assert_called_once_with()
+        root_bind.mount_kernel_file_systems.assert_called_once_with(None)
 
     @patch('kiwi.system.prepare.RootInit')
     @patch('kiwi.system.prepare.RootBind')
@@ -121,7 +121,61 @@ class TestSystemPrepare:
             root_init
         )
         root_bind.setup_intermediate_config.assert_called_once_with()
-        root_bind.mount_kernel_file_systems.assert_called_once_with()
+        root_bind.mount_kernel_file_systems.assert_called_once_with(None)
+        assert system.issue_message == '{headline}: {reason}'
+
+    @patch('kiwi.system.prepare.RootImport.new')
+    @patch('kiwi.system.prepare.RootInit')
+    @patch('kiwi.system.prepare.RootBind')
+    @patch('kiwi.logger.Logger.get_logfile')
+    def test_init_with_derived_from_image_for_delta_root(
+        self, mock_get_logfile, mock_root_bind, mock_root_init, mock_root_import
+    ):
+        mock_get_logfile.return_value = 'logfile'
+        description = XMLDescription(
+            description='../data/example_config.xml',
+            derived_from='derived/description'
+        )
+        xml = description.load()
+
+        root_init = MagicMock()
+        mock_root_init.return_value = root_init
+        root_import = Mock()
+        root_import.overlay_data = Mock()
+
+        mock_root_import.return_value = root_import
+        root_bind = MagicMock()
+        root_bind.root_dir = 'root_dir'
+        mock_root_bind.return_value = root_bind
+        state = XMLState(
+            xml, profiles=['containerFlavour'], build_type='docker'
+        )
+        uri = Mock()
+        get_derived_from_image_uri = Mock(
+            return_value=uri
+        )
+        get_delta_root = Mock(
+            return_value=True
+        )
+        state.get_derived_from_image_uri = get_derived_from_image_uri
+        state.build_type.get_delta_root = get_delta_root
+        system = SystemPrepare(
+            xml_state=state, root_dir='root_dir',
+        )
+        mock_root_init.assert_called_once_with(
+            'root_dir', False
+        )
+        root_init.create.assert_called_once_with()
+        mock_root_import.assert_called_once_with(
+            'root_dir', uri,
+            state.build_type.get_image()
+        )
+        root_import.overlay_data.assert_called_once_with()
+        mock_root_bind.assert_called_once_with(
+            root_init
+        )
+        root_bind.setup_intermediate_config.assert_called_once_with()
+        root_bind.mount_kernel_file_systems.assert_called_once_with(True)
         assert system.issue_message == '{headline}: {reason}'
 
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
@@ -311,7 +365,7 @@ class TestSystemPrepare:
         )
         tar.extract.assert_called_once_with('root_dir')
         self.manager.post_process_install_requests_bootstrap.assert_called_once_with(
-            self.system.root_bind
+            self.system.root_bind, None
         )
 
     @patch('kiwi.system.prepare.RootInit')
@@ -414,6 +468,15 @@ class TestSystemPrepare:
             [call(self.system.root_bind), call(self.system.root_bind)]
         )
 
+    @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
+    @patch('kiwi.system.prepare.Command.run')
+    def test_pinch_system_in_delta_root_mode(self, mock_Command_run, mock_poll):
+        self.system.delta_root = True
+        self.system.pinch_system(self.manager)
+        mock_Command_run.assert_called_once_with(
+            ['rsync', '-a', 'root_dir_cow/', 'root_dir_cow_before_pinch']
+        )
+
     @patch('kiwi.system.prepare.CommandProcess.poll_show_progress')
     def test_pinch_system_raises(self, mock_poll):
         mock_poll.side_effect = Exception
