@@ -15,12 +15,67 @@ class TestProfile:
         self.profile = Profile(
             XMLState(description.load())
         )
+        live_description = XMLDescription(
+            '../data/example_dot_profile_live_config.xml'
+        )
+        self.live_profile = Profile(
+            XMLState(live_description.load())
+        )
 
     def setup_method(self, cls):
         self.setup()
 
     @patch('kiwi.path.Path.which')
-    def test_create(self, mock_which):
+    def test_create_live(self, mock_which):
+        mock_which.return_value = 'cp'
+        self.live_profile.create(self.profile_file)
+        os.remove(self.profile_file)
+        assert self.live_profile.dot_profile == {
+            'kiwi_iname': 'LiveImage',
+            'kiwi_displayname': 'Live',
+            'kiwi_profiles': '',
+            'kiwi_delete': '',
+            'kiwi_type': 'iso',
+            'kiwi_compressed': None,
+            'kiwi_boot_timeout': None,
+            'kiwi_wwid_wait_timeout': None,
+            'kiwi_hybridpersistent': True,
+            'kiwi_hybridpersistent_filesystem': 'ext4',
+            'kiwi_initrd_system': 'dracut',
+            'kiwi_ramonly': None,
+            'kiwi_target_blocksize': None,
+            'kiwi_target_removable': None,
+            'kiwi_cmdline': 'console=ttyS0',
+            'kiwi_firmware': 'bios',
+            'kiwi_bootloader': 'grub2',
+            'kiwi_bootloader_console': 'default:default',
+            'kiwi_btrfs_root_is_snapshot': None,
+            'kiwi_gpt_hybrid_mbr': None,
+            'kiwi_devicepersistency': None,
+            'kiwi_installboot': None,
+            'kiwi_bootkernel': None,
+            'kiwi_fsmountoptions': None,
+            'kiwi_bootprofile': None,
+            'kiwi_vga': None,
+            'kiwi_startsector': 2048,
+            'kiwi_luks_empty_passphrase': False,
+            'kiwi_live_volid': 'CDROM',
+            'kiwi_iversion': '1.1.0',
+            'kiwi_showlicense': None,
+            'kiwi_keytable': 'us.map.gz',
+            'kiwi_timezone': 'Europe/Berlin',
+            'kiwi_language': 'en_US',
+            'kiwi_splash_theme': None,
+            'kiwi_loader_theme': None,
+            'kiwi_strip_delete': '',
+            'kiwi_strip_tools': '',
+            'kiwi_strip_libs': '',
+            'kiwi_drivers': '',
+            'kiwi_rootpartuuid': None
+        }
+
+    @patch('kiwi.path.Path.which')
+    def test_create_oem(self, mock_which):
         mock_which.return_value = 'cp'
         self.profile.create(self.profile_file)
         os.remove(self.profile_file)
@@ -40,7 +95,7 @@ class TestProfile:
             'kiwi_compressed': None,
             'kiwi_delete': '',
             'kiwi_devicepersistency': None,
-            'kiwi_bootloader_console': None,
+            'kiwi_bootloader_console': 'default:default',
             'kiwi_displayname': 'schäfer',
             'kiwi_drivers': '',
             'kiwi_firmware': 'efi',
