@@ -6,7 +6,6 @@ from mock import (
 from pytest import (
     raises, fixture
 )
-import hashlib
 import mock
 
 from kiwi.system.uri import Uri
@@ -110,6 +109,17 @@ class TestUri:
         uri = Uri('/path/to/repo')
         assert uri.is_remote() is False
 
+    def test_uri_needs_encoding(self):
+        uri = Uri(
+            'https://user@mycompany.com:token_password@'
+            'artifactory-edge.mycompany.com/artifactory/'
+            'some_rpm_path/Base-Prod/sample.rpm'
+        )
+        assert uri.translate(False) == \
+            'https://user%40mycompany.com:token_password@' \
+            'artifactory-edge.mycompany.com/artifactory/' \
+            'some_rpm_path/Base-Prod/sample.rpm'
+
     @patch('kiwi.system.uri.Defaults.is_buildservice_worker')
     def test_is_remote_in_buildservice(
         self, mock_buildservice
@@ -140,11 +150,14 @@ class TestUri:
         uri = Uri('httpx://example.com', 'rpm-md')
         assert uri.is_public() is False
 
-    def test_alias(self):
+    def test_alias_is_str(self):
         uri = Uri('https://example.com', 'rpm-md')
-        assert uri.alias() == hashlib.md5(
-            'https://example.com'.encode()).hexdigest(
-        )
+        assert isinstance(uri.alias(), str) is True
+
+    def test_alias_is_uniq(self):
+        uri1 = Uri('https://example.com', 'rpm-md')
+        uri2 = Uri('https://example.com', 'rpm-md')
+        assert uri1.alias() != uri2.alias()
 
     def test_credentials_file_name(self):
         uri = Uri(
