@@ -36,12 +36,6 @@ class TestSystemPrepareTask:
             return_value=self.runtime_checker
         )
 
-        self.runtime_config = mock.Mock()
-        self.runtime_config.get_disabled_runtime_checks.return_value = []
-        kiwi.tasks.base.RuntimeConfig = mock.Mock(
-            return_value=self.runtime_config
-        )
-
         self.system_prepare = mock.Mock()
         kiwi.tasks.system_prepare.SystemPrepare = mock.Mock(
             return_value=self.system_prepare
@@ -67,6 +61,7 @@ class TestSystemPrepareTask:
             return_value=mock.Mock()
         )
         self.task = SystemPrepareTask()
+        self.task.runtime_config = mock.MagicMock()
 
     def setup_method(self, cls):
         self.setup()
