@@ -17,6 +17,9 @@ class TestCodec:
     def setup(self):
         self.literal = bytes(b'\xc3\xbc')
 
+    def setup_method(self, cls):
+        self.setup()
+
     @patch('kiwi.utils.codec.Codec._wrapped_decode')
     def test_decode_ascii_failure(self, mock_decode):
         msg = 'utf-8 compatible string'
