@@ -53,6 +53,9 @@ class TestVolumeManagerBase:
     def setup_method(self, cls, mock_path):
         self.setup()
 
+    def test_get_root_volume_name(self):
+        assert self.volume_manager.get_root_volume_name() == '/'
+
     @patch('os.path.exists')
     def test_init_custom_args(self, mock_exists):
         mock_exists.return_value = True
@@ -243,6 +246,14 @@ class TestVolumeManagerBase:
         )
         assert self.volume_manager.get_mountpoint() == 'mountpoint'
 
+    def test_create_verity_layer(self):
+        with raises(NotImplementedError):
+            self.volume_manager.create_verity_layer()
+
+    def test_create_verification_metadata(self):
+        with raises(NotImplementedError):
+            self.volume_manager.create_verification_metadata('/some/device')
+
     @patch('kiwi.volume_manager.base.Temporary')
     def test_setup_mountpoint(self, mock_Temporary):
         mock_Temporary.return_value.new_dir.return_value.name = 'tmpdir'
