@@ -1,3 +1,4 @@
+import logging
 from mock import patch
 import mock
 from builtins import bytes
@@ -5,6 +6,7 @@ from lxml import etree
 from pytest import raises
 from collections import namedtuple
 from kiwi.utils.temporary import Temporary
+from pytest import fixture
 
 from kiwi.xml_description import XMLDescription
 
@@ -20,6 +22,10 @@ from kiwi.exceptions import (
 
 
 class TestSchema:
+    @fixture(autouse=True)
+    def inject_fixtures(self, caplog):
+        self._caplog = caplog
+
     def setup(self):
         test_xml = bytes(
             b"""<?xml version="1.0" encoding="utf-8"?>
@@ -144,6 +150,9 @@ class TestSchema:
             test_xml_extension_invalid_file.name
         )
 
+    def setup_method(self, cls):
+        self.setup()
+
     def test_load_schema_from_xml_content(self):
         schema = etree.parse('../../kiwi/schema/kiwi.rng')
         lookup = '{http://relaxng.org/ns/structure/1.0}attribute'
@@ -163,6 +172,15 @@ class TestSchema:
         with raises(KiwiSchemaImportError):
             self.description_from_file.load()
 
+    @patch('importlib.import_module')
+    def test_load_schema_from_xml_content_skipping_isoschematron(
+        self, mock_import_module
+    ):
+        mock_import_module.side_effect = Exception
+        with self._caplog.at_level(logging.WARNING):
+            self.description_from_data.load()
+            assert 'schematron validation skipped:' in self._caplog.text
+
     @patch('lxml.isoschematron.Schematron')
     @patch('lxml.etree.RelaxNG')
     @patch('lxml.etree.parse')
